# Changelog

## [0.0.1a1](https://github.com/OpenVoiceOS/ovos-lang-parser/tree/0.0.1a1) (2025-03-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-lang-parser/compare/0.0.0...0.0.1a1)

**Merged pull requests:**

- da-dk/translate [\#3](https://github.com/OpenVoiceOS/ovos-lang-parser/pull/3) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
